@@ -113,8 +113,8 @@ gchar *fix_separators(gchar *source)
 				*pointer = '/';
 
 				// skip /./ and similar
-				if ((source[co+1] == '.') && (is_separator(source[co+2]))) {
-					co+=2;
+				if ((source[co + 1] == '.') && (is_separator(source[co + 2]))) {
+					co += 2;
 				}
 
 
@@ -135,7 +135,7 @@ gchar *fix_separators(gchar *source)
 /**
  *
  */
-gchar *fix_path(char *base_dir,char *temp)
+gchar *fix_path(char *base_dir, char *temp)
 {
 	// first, make slashes real ones for the platform.
 	gchar *curr = g_strdup(base_dir);
@@ -151,26 +151,26 @@ gchar *fix_path(char *base_dir,char *temp)
 
 	if (!g_path_is_absolute(infile)) {
 		int co;
-		for (co = 0; co<(int)strlen(infile); co++) {
+		for (co = 0; co < (int)strlen(infile); co++) {
 			char ch = infile[co];
 
 			if (!is_separator(ch)) {
 
 				if (current_path != NULL) {
-					gchar *buf = g_strdup_printf("%s%c",current_path,ch);
+					gchar *buf = g_strdup_printf("%s%c", current_path, ch);
 
 					g_free(current_path);
 
 					current_path = buf;
 
 				} else {
-					current_path = g_strdup_printf("%c",ch);
+					current_path = g_strdup_printf("%c", ch);
 				}
 
 			} else {
 				//g_print("%s\n",current_path);
 
-				if (strcmp(current_path,"..") == 0) {
+				if (strcmp(current_path, "..") == 0) {
 					//g_print("Up! curr:%s\n",out_path);
 
 					//file_pointer = &infile[co];
@@ -205,6 +205,8 @@ gchar *fix_path(char *base_dir,char *temp)
 	//gchar *new_res = g_strdup_printf("%s%c%s",out_path,G_DIR_SEPARATOR,get_filename_from_full_path(file_pointer));
 	gchar *new_res = g_strdup_printf("%s%c%s", out_path, G_DIR_SEPARATOR, tempfile);
 
+	if (infile != 0) g_free(infile);
+
 	g_free(curr);
 	//g_free(infile);
 
@@ -222,7 +224,7 @@ void init_file_utils()
 
 	g_free(temp);
 
-	if (current_directory[strlen(current_directory)-1] != G_DIR_SEPARATOR) {
+	if (current_directory[strlen(current_directory) - 1] != G_DIR_SEPARATOR) {
 
 	}
 }
@@ -387,9 +389,9 @@ gboolean relative_path_to_abs_path(gchar *relativePath, gchar **absPath, const g
 	int absPathLength;
 	int co;
 
-	for (co=0; co<strlen(relativePath); co++) {
-		if ((relativePath[co]=='/') || (relativePath[co]=='\\')) {
-			relativePath[co]=G_DIR_SEPARATOR;
+	for (co = 0; co < strlen(relativePath); co++) {
+		if ((relativePath[co] == '/') || (relativePath[co] == '\\')) {
+			relativePath[co] = G_DIR_SEPARATOR;
 		}
 	}
 
@@ -462,7 +464,7 @@ gboolean relative_path_to_abs_path(gchar *relativePath, gchar **absPath, const g
 		}
 
 		if (tail != NULL) {
-			g_memmove(localAbsPath + i, tail, tailLength);
+			memmove(localAbsPath + i, tail, tailLength);
 
 			absPathLength -= (tail - localAbsPath - i);
 		}
@@ -526,6 +528,12 @@ int get_number_of_files_in_folder(gchar *folder_name)
 		};
 	}
 
+	g_slist_foreach(file_list, (GFunc)g_free, NULL);
+	g_slist_free(file_list);
+
+	g_slist_foreach(folder_list, (GFunc)g_free, NULL);
+	g_slist_free(folder_list);
+
 	return result;
 }
 
@@ -543,10 +551,9 @@ gboolean is_string_folder(gchar *instring)
 
 	if (dir) {
 		result = TRUE;
+		g_dir_close(dir);
 	}
 
-	if (dir) g_dir_close(dir);
-
 	return result;
 }
 
@@ -558,17 +565,18 @@ gchar *clean_folder(gchar *infolder)
 {
 	gchar *result = NULL;
 
-	gchar *temp = infolder;
-
-	int len = strlen(infolder);
-
 	if (g_strcmp0(infolder, "./") == 0) {
 		result = g_strdup_printf(".");
 
 		return result;
 	}
 
-	if (temp) {
+	if (infolder) {
+
+		gchar *temp = infolder;
+
+		int len = strlen(temp);
+
 		if ((temp[0] == '.') && (temp[1] == G_DIR_SEPARATOR)) {
 
 			temp += 2;
