@@ -1,7 +1,7 @@
 /**
  * gui.c - GUI code for SciteProj
  *
- *  Copyright 2006 Roy Wood, 2009-2019 Andreas Rönnquist
+ *  Copyright 2006 Roy Wood, 2009-2020 Andreas Rönnquist
  *
  * This file is part of SciteProj.
  *
@@ -508,7 +508,7 @@ static void tree_row_activated_cb(GtkTreeView *treeView,
 	// We can only open files
 
 	if (nodeItemType != ITEMTYPE_FILE) {
-		switch_folder_icon(treeView,path);
+		switch_folder_icon(treeView, path);
 		goto EXITPOINT;
 	}
 
@@ -532,7 +532,7 @@ static void tree_row_activated_cb(GtkTreeView *treeView,
 				send_scite_command((gchar*)"focus:0", NULL);
 			}
 
-			add_file_to_recent(fixed,NULL);
+			add_file_to_recent(fixed, NULL);
 
 			gchar *statusbar_text = g_strdup_printf(_("Opened %s"),
 			                                        remove_newline(get_filename_from_full_path(command)));
@@ -551,7 +551,7 @@ EXITPOINT:
 		could_not_open_string = g_strdup_printf(_("Could not open selected file:"));
 
 		dialog = gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
-		                                _("%s\n\n%s"), could_not_open_string, err->message);
+		                                "%s\n\n%s", could_not_open_string, err->message);
 
 		gtk_dialog_run(GTK_DIALOG (dialog));
 
@@ -682,7 +682,7 @@ void set_window_title(const gchar *newName)
 	g_assert(newName != NULL);
 
 	gchar *temp_string = g_new(gchar, 512);
-	g_snprintf(temp_string,512, "%s", newName);
+	g_snprintf(temp_string, 512, "%s", newName);
 
 	gtk_window_set_title(GTK_WINDOW(sMainWindow), temp_string);
 
