@@ -1,7 +1,7 @@
 /**
  * load_folder.c - folder loading support for sciteproj
  *
- *  Copyright 2012-2017 Andreas Rönnquist
+ *  Copyright 2012-2020 Andreas Rönnquist
  *
  * This file is part of SciteProj.
  *
@@ -95,13 +95,15 @@ GSList *load_folder_to_list(gchar *folder_path, gboolean read_directories, GComp
 {
 	GSList *result_list = NULL;
 
-	GDir *dir=g_dir_open(folder_path, 0, NULL);
+	GDir *dir = g_dir_open(folder_path, 0, NULL);
 
 	const gchar *short_filename;
 
 	while((short_filename = g_dir_read_name(dir))) {
 
-		gchar *temp_file = g_build_filename(folder_path, short_filename, NULL);
+		gchar *current_filename = g_strdup(short_filename);
+
+		gchar *temp_file = g_build_filename(folder_path, current_filename, NULL);
 
 		if (read_directories) {
 
@@ -109,10 +111,10 @@ GSList *load_folder_to_list(gchar *folder_path, gboolean read_directories, GComp
 
 				if (filter_list != NULL) {
 					if (!ignore_pattern_matches(folder_path, short_filename, filter_list)) {
-						result_list = g_slist_prepend(result_list, (gpointer)short_filename);
+						result_list = g_slist_prepend(result_list, (gpointer)current_filename);
 					}
 				} else {
-					result_list = g_slist_prepend(result_list, (gpointer)short_filename);
+					result_list = g_slist_prepend(result_list, (gpointer)current_filename);
 				}
 			}
 
@@ -131,6 +133,8 @@ GSList *load_folder_to_list(gchar *folder_path, gboolean read_directories, GComp
 		}
 	}
 
+	g_dir_close(dir);
+
 	result_list = g_slist_sort(result_list, compare_func);
 
 	return result_list;
