@@ -1,7 +1,7 @@
 /**
  * properties_dialog.c - Properties Dialogs code for SciteProj
  *
- *  Copyright 2009-2018 Andreas Rönnquist
+ *  Copyright 2009-2020 Andreas Rönnquist
  *
  * This file is part of SciteProj.
  *
@@ -58,7 +58,7 @@ void group_properties_gui(GtkTreeModel *tree_model, GtkTreeIter *iter)
 
 	GtkWidget *table;
 	GtkWidget *label1, *label2;
-	GtkWidget *filename, *filepath_label;
+	GtkWidget *filename, *filepath_entry;
 	GtkWidget *container_box;
 
 	gchar *filePath = NULL;
@@ -77,14 +77,21 @@ void group_properties_gui(GtkTreeModel *tree_model, GtkTreeIter *iter)
 	gtk_dialog_set_default_response(GTK_DIALOG(dialog), GTK_RESPONSE_OK);
 
 	label1 = gtk_label_new(_("Group name:"));
-	label2 = gtk_label_new(_("Full folder:"));
+	label2 = gtk_label_new(_("Complete folder:"));
+
+	gtk_widget_set_valign(label2, GTK_ALIGN_CENTER);
 
 	filename = gtk_label_new(nodename);
 
-	filepath_label = gtk_label_new(filePath);
+	//filepath_label = gtk_label_new(filePath);
+	filepath_entry = gtk_entry_new();
+
+	gtk_entry_set_text(GTK_ENTRY(filepath_entry), filePath);
+	gtk_editable_set_editable(GTK_EDITABLE(filepath_entry), FALSE);
+	gtk_widget_set_can_focus(GTK_WIDGET(filepath_entry), FALSE);
 
 	my_set_align(filename);
-	my_set_align(filepath_label);
+	my_set_align(filepath_entry);
 
 	my_set_align(label1);
 	my_set_align(label2);
@@ -95,11 +102,18 @@ void group_properties_gui(GtkTreeModel *tree_model, GtkTreeIter *iter)
 	gtk_grid_attach(GTK_GRID(table), label2, 0, 1, 1, 1);
 
 	gtk_grid_attach(GTK_GRID(table), filename, 1, 0, 4, 1);
-	gtk_grid_attach(GTK_GRID(table), filepath_label, 1, 1, 4, 1);
+	gtk_grid_attach(GTK_GRID(table), filepath_entry, 1, 1, 4, 1);
 
 	gtk_grid_set_row_spacing(GTK_GRID (table), 6);
 	gtk_grid_set_column_spacing(GTK_GRID (table), 6);
 
+	gtk_widget_set_halign(filename, GTK_ALIGN_START);
+	gtk_widget_set_hexpand(filename, FALSE);
+	gtk_widget_set_halign(filepath_entry, GTK_ALIGN_FILL);
+	gtk_widget_set_hexpand(filepath_entry, TRUE);
+
+	gtk_widget_set_valign(label2, GTK_ALIGN_CENTER);
+
 	container_box = gtk_dialog_get_content_area(GTK_DIALOG(dialog));
 	gtk_box_pack_start(GTK_BOX(container_box), table, TRUE, TRUE, 0);
 
@@ -174,7 +188,19 @@ void file_properties_gui(GtkTreeModel *model, GtkTreeIter *iter)
 	label3 = gtk_label_new(_("File size:"));
 
 	filename = gtk_label_new(nodename);
-	path = gtk_label_new(absFilePath/*sClickedNodeName*/);
+	// path = gtk_label_new(absFilePath);
+	path = gtk_entry_new();
+
+	// buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(path));
+
+	gtk_entry_set_text(GTK_ENTRY(path), absFilePath);
+
+	gtk_editable_set_editable(GTK_EDITABLE(path), FALSE);
+	gtk_widget_set_can_focus(GTK_WIDGET(path), FALSE);
+
+	//gtk_widget_show(buffer);
+	gtk_widget_show(path);
+
 	filesize_label = gtk_label_new(size_string);
 
 	my_set_align(filename);
@@ -191,25 +217,33 @@ void file_properties_gui(GtkTreeModel *model, GtkTreeIter *iter)
 	gtk_grid_attach(GTK_GRID(table), label2, 0, 1, 1, 1);
 	gtk_grid_attach(GTK_GRID(table), label3, 0, 2, 1, 1);
 
-	gtk_grid_attach(GTK_GRID(table), filename, 1, 0, 4, 1);
-	gtk_grid_attach(GTK_GRID(table), path, 1, 1, 4, 1);
-	gtk_grid_attach(GTK_GRID(table), filesize_label, 1, 2, 4, 1);
+	gtk_grid_attach(GTK_GRID(table), filename,			1, 0, 1, 1);
+	gtk_grid_attach(GTK_GRID(table), path,					1, 1, 1, 1);
+	gtk_grid_attach(GTK_GRID(table), filesize_label,	1, 2, 1, 1);
 
 	gtk_grid_set_row_spacing (GTK_GRID (table), 6);
 	gtk_grid_set_column_spacing (GTK_GRID (table), 6);
 
+	gtk_widget_set_halign(filename, GTK_ALIGN_START);
+	gtk_widget_set_hexpand(filename, FALSE);
+	gtk_widget_set_halign(path, GTK_ALIGN_FILL);
+	gtk_widget_set_hexpand(path, TRUE);
+	gtk_widget_set_halign(filesize_label, GTK_ALIGN_START);
+	gtk_widget_set_hexpand(filesize_label, FALSE);
+
+	gtk_widget_set_valign(label2, GTK_ALIGN_CENTER);
+
+	set_dialog_transient(dialog);
 
 	container_box = gtk_dialog_get_content_area(GTK_DIALOG(dialog));
-	gtk_box_pack_start(GTK_BOX(container_box), table, TRUE, TRUE, 0);
-	
-	set_dialog_transient(dialog);
+
+	gtk_box_pack_end(GTK_BOX(container_box), table, TRUE, TRUE, 0);
 	
 	gtk_window_set_default_size(GTK_WINDOW(dialog), 500, 100);
-	gtk_window_set_resizable (GTK_WINDOW(dialog), FALSE);
+	gtk_window_set_resizable (GTK_WINDOW(dialog), TRUE);
 
 	gtk_widget_show_all(dialog);
 
-
 	gtk_dialog_run(GTK_DIALOG(dialog));
 
 
