@@ -1,7 +1,7 @@
 /**
  * string_utils.c - misc string utils for SciteProj
  *
- *  Copyright 2006 Roy Wood, 2009-2016 Andreas Rönnquist
+ *  Copyright 2006 Roy Wood, 2009-2017 Andreas Rönnquist
  *
  * This file is part of SciteProj.
  *
@@ -65,7 +65,7 @@ gboolean str_append(gchar **dst, const gchar *src, GError **err)
 		goto EXITPOINT;
 	}
 
-	g_memmove(newDst + dstLength, src, srcLength + 1);
+	memmove(newDst + dstLength, src, srcLength + 1);
 
 	*dst = newDst;
 
@@ -100,8 +100,8 @@ char *remove_newline( char *s )
 {
 	int len=strlen(s);
 
-	if (s[len-1] == '\n') {
-		s[len-1] = '\0';
+	if (s[len - 1] == '\n') {
+		s[len - 1] = '\0';
 	}
 
 	return s;
